@@ -26,16 +26,12 @@ import subprocess
 import os   # to delete files after calc.
 import sys  # to check whether running on Linux or Windows
 import datetime
-
+import time
+import tempfile  # to run mstm in temporary directory
 try:
     import matplotlib.pyplot as plt
 except ImportError:
     pass
-
-import time
-
-import tempfile  # to run mstm in temporary directory
-
 # use input in both python2 and python3
 try:
     input = raw_input
@@ -49,13 +45,13 @@ except NameError:
 
 
 class Profiler(object):
-    """
+    '''
     This class for benchmarking is from
     http://onesteptospace.blogspot.pt/2013/01/python.html
     Usage:
     >>> with Profiler() as p:
     >>>     // your code to be profiled here
-    """
+    '''
     def __enter__(self):
         self._startTime = time.time()
 
@@ -68,12 +64,12 @@ class SpheresOverlapError(Exception):
 
 
 class SPR(object):
-    """
+    '''
     Class for calculation of surface plasmin resonance (SPR),
     running MSTM external code.
     The MSTM executable should be set in MSTM_BIN environment
     variable. Default is ~/bin/mstm.x
-    """
+    '''
 
     environment_material = 'Air'
 
@@ -109,8 +105,7 @@ class SPR(object):
 
       'output_file': 'test.dat',         # should change for each run
 
-      'incident_or_target_frame': 0,     # Integer switch, relevant only for
-                                         # fixed orientation calculations
+      'incident_or_target_frame': 0,     # used for scattering matrix output
       'min_scattering_angle_deg': 0.0,
       'max_scattering_angle_deg': 180.0,
       'min_scattering_plane_angle_deg': 0.0,   # selects a plane for fixed orient.
@@ -282,24 +277,21 @@ class SPR(object):
                 self.extinction = []
                 self.absorbtion = []
                 self.scattering = []
-                for l in self.wavelengths:
-                    inFID = open(os.path.join(tmpdir,
-                                              'mstm_l%.0f.out' % (l * 1000)),
-                                 'r')
-                    while True:
-                        line = inFID.readline()
-                        if 'scattering matrix elements' in line:
-                            break
-                        elif 'total ext, abs, scat efficiencies' in line:
-                            values = map(float,
-                                         inFID.readline().strip().split())
-                            values = list(values)  # python3 is evil
-                            self.extinction.append(float(values[0]))
-                            self.absorbtion.append(float(values[1]))
-                            self.scattering.append(float(values[2]))
-                    inFID.close()
-                    os.remove(os.path.join(tmpdir,
-                                           'mstm_l%.0f.out' % (l * 1000)))
+                for lam in self.wavelengths:
+                    fnl = os.path.join(tmpdir, 'mstm_l%.0f.out' % (lam * 1000))
+                    with open(fnl, 'r') as fout:
+                        while True:
+                            line = fout.readline()
+                            if 'scattering matrix elements' in line:
+                                break
+                            elif 'total ext, abs, scat efficiencies' in line:
+                                values = map(float,
+                                             fout.readline().strip().split())
+                                values = list(values)  # python3 is evil
+                                self.extinction.append(float(values[0]))
+                                self.absorbtion.append(float(values[1]))
+                                self.scattering.append(float(values[2]))
+                    os.remove(fnl)
                 self.extinction = np.array(self.extinction)
                 self.absorbtion = np.array(self.absorbtion)
                 self.scattering = np.array(self.scattering)
@@ -307,11 +299,17 @@ class SPR(object):
                 self.write(outfn)
         return self.wavelengths, self.extinction
 
+
     def plot(self):
         '''
         Plot results with matplotlib.pyplot
         '''
-        plt.plot(self.wavelengths, self.extinction, 'r-', label='extinction')
+        if self.paramDict["fixed_or_random_orientation"] == 1:  # random
+            plt.plot(self.wavelengths, self.extinction, 'r-', label='extinction')
+        else:
+            plt.plot(self.wavelengths, self.extinction_par, 'r-', label='extinction par.')
+            plt.plot(self.wavelengths, self.extinction_ort, 'b-', label='extinction ort.')
+        plt.legend()
         plt.show()
         return plt
 
@@ -336,8 +334,8 @@ class SPR(object):
 
     def set_incident_field(self, fixed=False, azimuth_angle=0.0,
                            polar_angle=0.0, polarization_angle=0.0):
-        """
-            Set the parameters of incident wave
+        '''
+            Set incident wave orientation and polarization
 
             Parameters:
 
@@ -348,15 +346,16 @@ class SPR(object):
                 azimuth_angle, polar_angle: float (degrees)
 
                 polarization_angle: float (degrees)
+                    !sensible only for near field calculation!
                     polarization angle relative to the `k-z` palne.
                     0 - X-polarized, 90 - Y-polarized (if `azimuth` and
                     `polar` angles are zero).
-        """
+        '''
         if not fixed:
             self.paramDict['fixed_or_random_orientation'] = 1  # random
         else:
             self.paramDict['fixed_or_random_orientation'] = 0  # fixed
-            self.paramDict['incident_azimuth_angle_deg'] = polarization_angle
+            self.paramDict['incident_azimuth_angle_deg'] = azimuth_angle
             self.paramDict['incident_polar_angle_deg'] = polar_angle
             self.paramDict['polarization_angle_deg'] = polarization_angle
 
@@ -406,12 +405,12 @@ class Material(object):
             k = np.sqrt((mod - np.real(eps)) / 2)
         else:
             try:
-                np.complex(file_name)
+                np.cdouble(file_name)
                 is_complex = True
             except ValueError:
                 is_complex = False
             if is_complex:
-                nk = np.complex(file_name)
+                nk = np.cdouble(file_name)
                 n = np.array([np.real(nk), np.real(nk)])
                 k = np.array([np.imag(nk), np.imag(nk)])
             else:
@@ -475,7 +474,7 @@ class Material(object):
             filled/created fig and axs objects
         """
         if wls is None:
-            wls = np.linspace(300, 800, 501)
+            wls = np.linspace(300, 800, 500)
         flag = fig is None
         if flag:
             fig = plt.figure()
@@ -886,15 +885,18 @@ if __name__ == '__main__':
         spr = SPR(wls)
         spr.environment_material = 'glass'
         # spr.set_spheres(SingleSphere(0.0, 0.0, 0.0, 25.0, 'etaGold.txt'))
-        spheres = ExplicitSpheres(2, [0, 0, 0, 10, 0, 0, 0, 12],
+        spheres = ExplicitSpheres(2, [-20, 0, 0, 10, 10, 0, 0, 12],
                                   mat_filename=['nk/etaGold.txt',
                                                 'nk/etaSilver.txt'])
         # spheres = ExplicitSpheres(2, [0,0,0,20,0,0,0,21],
         #                           mat_filename='etaGold.txt')
         spr.set_spheres(spheres)
+        spr.set_incident_field(fixed=True, azimuth_angle=90, polar_angle=90,
+                               polarization_angle=45)
         # spr.set_spheres(LogNormalSpheres(27, 0.020, 0.9, 0.050 ))
         # calculate!
         # spr.command = ''
         spr.simulate()
+    spr.write('test.dat')
     spr.plot()
-    # ~ input('Press enter')
+    input('Press enter')
